<?php

namespace Teknisa\TCO\Services;

use Zeedhi\Framework\DB\StoredProcedure\StoredProcedure;
use Zeedhi\Framework\DB\StoredProcedure\Param;

class Tco01009AnaliseCustosService extends \Teknisa\GER\Controllers\TeknisaCrud{
    
    protected $crudService;
    protected $environment;
    protected $entityManager;

    public function __construct($crudService, $parameterBag, $environment, $entityManager) {
        $this->crudService = $crudService;
        $this->environment = $environment;
        $this->entityManager = $entityManager;
    }
    
    public function procedureAnaliseCusto($row) {
        $connection = $this->entityManager->getConnection();
        
        $procedure = new StoredProcedure($connection, 'IMPORTA_CARDBASE_NO_CARDTRAB');
        
        $procedure->addParam(new Param('P_NRCARDAPIOBASE',          Param::PARAM_INPUT,  $row['NRCARDAPIOBASE'],             Param::PARAM_TYPE_INT));
        $procedure->addParam(new Param('P_IDORIGEM',                Param::PARAM_INPUT,  $row["IDORIGEM"],                   Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_NRATIVCLISEGMER',         Param::PARAM_INPUT,  $row['NRATIVCLISEGMER'],            Param::PARAM_TYPE_INT));
        $procedure->addParam(new Param('P_CDREGIAO',                Param::PARAM_INPUT,  $row['CDREGIAO'],                   Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_VRPEACRESCUSTO',          Param::PARAM_INPUT,  $row['VRPEACRESCUSTO'],             Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_NRTIPOPUBLICO',           Param::PARAM_INPUT,  $row['NRTIPOPUBLICO'],              Param::PARAM_TYPE_INT));
        $procedure->addParam(new Param('P_QTSEGSEX',                Param::PARAM_INPUT,  $row['QTSEGSEX'],                   Param::PARAM_TYPE_INT));
        $procedure->addParam(new Param('P_QTSABADO',                Param::PARAM_INPUT,  $row['QTSABADO'],                   Param::PARAM_TYPE_INT));
        $procedure->addParam(new Param('P_QTDOMFERI',               Param::PARAM_INPUT,  $row['QTDOMFERI'],                  Param::PARAM_TYPE_INT));
        $procedure->addParam(new Param('P_QTTURNOS',                Param::PARAM_INPUT,  $row['QTTURNOS'],                   Param::PARAM_TYPE_INT));
        $procedure->addParam(new Param('P_CONFIGURACOES',           Param::PARAM_INPUT,  $row['L_NRCONFIGCARDBASE'],         Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_GRUPOS',                  Param::PARAM_INPUT,  $row['L_PORCGRAMCARDBASE'],         Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_DTCUSTO',                 Param::PARAM_INPUT,  $row['DTCUSTO'],                    Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_NRCARDTRABCOMPLEMENTADO', Param::PARAM_INPUT,  null,                               Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_NRORG',                   Param::PARAM_INPUT,  $this->environment->getNrOrgTrab(), Param::PARAM_TYPE_INT));
        $procedure->addParam(new Param('P_CDOPERADOR',              Param::PARAM_INPUT,  $this->environment->getCdoperador(),Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_CDFILIALLOGADA',          Param::PARAM_INPUT,  $this->environment->getCdFilial(),  Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_NRCARDAPIOTRAB',          Param::PARAM_OUTPUT, null,                               Param::PARAM_TYPE_STR, 20));
        $procedure->addParam(new Param('P_LISTAERROS',              Param::PARAM_OUTPUT, null,                               Param::PARAM_TYPE_STR, 20));
        $result = $procedure->execute();
        return $result;
    }
    
    public function procedureAnaliseCustoServComplementar($row) {
        $connection = $this->entityManager->getConnection();
        
        $procedure = new StoredProcedure($connection, 'CALC_SERVCOMPLEMENTAR');
        
        $procedure->addParam(new Param('P_NRCARDAPIOBASE',          Param::PARAM_INPUT,  $row['NRCARDBASECOMPLEMENTAR'],     Param::PARAM_TYPE_INT));
        $procedure->addParam(new Param('P_IDORIGEM',                Param::PARAM_INPUT,  $row["IDORIGEM"],                   Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_NRATIVCLISEGMER',         Param::PARAM_INPUT,  $row['NRATIVCLISEGMER'],            Param::PARAM_TYPE_INT));
        $procedure->addParam(new Param('P_CDREGIAO',                Param::PARAM_INPUT,  $row['CDREGIAO'],                   Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_VRPEACRESCUSTO',          Param::PARAM_INPUT,  $row['VRPEACRESCUSTO'],             Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_NRTIPOPUBLICO',           Param::PARAM_INPUT,  $row['NRTIPOPUBLICO'],              Param::PARAM_TYPE_INT));
        $procedure->addParam(new Param('P_QTSEGSEX',                Param::PARAM_INPUT,  $row['QTSEGSEX'],                   Param::PARAM_TYPE_INT));
        $procedure->addParam(new Param('P_QTSABADO',                Param::PARAM_INPUT,  $row['QTSABADO'],                   Param::PARAM_TYPE_INT));
        $procedure->addParam(new Param('P_QTDOMFERI',               Param::PARAM_INPUT,  $row['QTDOMFERI'],                  Param::PARAM_TYPE_INT));
        $procedure->addParam(new Param('P_QTTURNOS',                Param::PARAM_INPUT,  $row['QTTURNOS'],                   Param::PARAM_TYPE_INT));
        $procedure->addParam(new Param('P_DTCUSTO',                 Param::PARAM_INPUT,  $row['DTCUSTO'],                    Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_NRCARDTRABCOMPLEMENTADO', Param::PARAM_INPUT,  $row['NRCARDTRABCOMPLEMENTADO'],    Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_NRORG',                   Param::PARAM_INPUT,  $this->environment->getNrOrgTrab(), Param::PARAM_TYPE_INT));
        $procedure->addParam(new Param('P_CDOPERADOR',              Param::PARAM_INPUT,  $this->environment->getCdoperador(),Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_CDFILIALLOGADA',          Param::PARAM_INPUT,  $this->environment->getCdFilial(),  Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_NRCARDAPIOTRAB',          Param::PARAM_OUTPUT, null,                               Param::PARAM_TYPE_STR, 20));
        $procedure->addParam(new Param('P_LISTAERROS',              Param::PARAM_OUTPUT, null,                               Param::PARAM_TYPE_STR, 20));
        
        $result = $procedure->execute();
        return $result;
    }
    
    public function apagaCardapioTrab($row) {
        $connection = $this->entityManager->getConnection();
        $procedure = new StoredProcedure($connection, 'DELETA_CARDTRAB');
        
        $procedure->addParam(new Param('P_NRCARDAPIOBASE', Param::PARAM_INPUT, $row['NRCARDAPIOTRAB'], Param::PARAM_TYPE_INT));
        
        $result = $procedure->execute();
        return $result;
    }
      public function vericaGrupoTipoPrato($row){
        $sql = "SELECT DISTINCT GRTP.CDGRTIPOPR,GRTP.NMGRTIPOPR,CB.NRORG,CB.IDATIVO,CGB.NRCONFGRUPTPCARDBASE ,CGB.NRPORCIONAMENTO,PC.CDPORCIONAMENTO,  
        PC.NMPORCIONAMENTO, CGB.NRGRAMATURACARDBASE, GMCB.VRGRAMATURA, GMCB.SGUNIDADE,CGB.IDTIPOGRAMATURA
        FROM CONFIGCARDBASE CB LEFT JOIN TIPOPRAT TP ON TP.CDTIPOPRAT = CB.CDTIPOPRAT LEFT JOIN GRTIPOPR GRTP ON GRTP.CDGRTIPOPR = TP.CDGRTIPOPR 
        LEFT JOIN CONFGRUPTPCARDBASE CGB ON CGB.NRCARDAPIOBASE = CB.NRCARDAPIOBASE AND CGB.CDGRTIPOPR = GRTP.CDGRTIPOPR LEFT JOIN PORCIONAMENTO PC ON PC.NRPORCIONAMENTO = CGB.NRPORCIONAMENTO 
        LEFT JOIN GRAMATURACARDBASE GMCB ON GMCB.NRGRAMATURACARDBASE = CGB.NRGRAMATURACARDBASE WHERE CB.NRCARDAPIOBASE = :NRCARDAPIOBASE AND CB.IDCLASSIFICACAO = 'ALIMENTAR'";

        $params = array(
            "NRCARDAPIOBASE" => $row['NRCARDAPIOBASE']
        );

        $query = $this->entityManager->getConnection()->prepare($sql);
        $query->execute($params);
        $result = $query->fetchAll();

        return $result;
    }
}